@@ -203,5 +203,5 @@ class connector:
 	def get_level(self, login):
 		url = f"/users/{login}/cursus_users?filter[cursus_id]=21"
 		data = self.get(url)
-		return (data['level'])
+		return (data[0]['level'])
 
